@@ -1,6 +1,5 @@
 from faker.generator import Generator  # noqa F401
 from faker.factory import Factory  # noqa F401
+from faker.proxy import Faker  # noqa F401
 
-VERSION = '2.0.5'
-
-Faker = Factory.create
+VERSION = '3.0.0'
